#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/bin/mail-panda-update.sh - update or generate new configuration
#
# Copyright (c) 2020-2020  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation   : 2020-05-25 jed
# Last Update: $Id: mail-panda-update.sh 79220 2020-07-06 19:39:26Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# read eislib etc.
. /var/install/include/eislib
. /var/install/include/configlib
. /var/install/include/jedlib

. /var/install/include/jedlib

# debug mode: true/false
#debug=true
if ${debug:-false}
then
    exec 2>/tmp/$(basename ${0})-update-trace$$.log
    set -x
    ask_debug=true
    export ask_debug
fi

#------------------------------------------------------------------------------
# function: variable is set
#
# input:  $1 - variable name
# return:  0 - variable set
#          1 - variable not set
#------------------------------------------------------------------------------
variable_set ()
{
    local _vs_var1
    local _vs_var2
    local _vs_ret

    eval _vs_var1=\$"${1}"
    eval _vs_var2=\$"{${1}+EMPTY}"

    if [ -z "${_vs_var1}" ]
    then
        if [ "${_vs_var2}" = 'EMPTY' ]
        then
            # variable is empty, but set
            _vs_ret=0
        else
            # variable is not set
            _vs_ret=1
        fi
    else
        # variable has a value
        _vs_ret=0
    fi

    return ${_vs_ret}
}

#------------------------------------------------------------------------------
# print variable only if it has been set
# $1 - variable name
# $2 - comment
#------------------------------------------------------------------------------
printsetvar ()
{
    if variable_set "${1}"
    then
        printvar "${1}" "${2}"
    fi
}

#------------------------------------------------------------------------------
# rename variables
#------------------------------------------------------------------------------
rename_variables ()
{
    local _rv_renamed
    local _rv_output_file

    _rv_renamed=0
    _rv_output_file=`mktemp -t ${module_name}.XXXXXXXXX`

    if [ ${_rv_renamed} -eq 1 ]
    then
        modflag=1
        myecho --pack ${module_name} --force-output "renaming parameter(s) ..."
        cat ${_rv_output_file}
        myecho --pack ${module_name} --force-output --info "... read documentation for renamed parameter(s)!"
    fi

    rm -f ${_rv_output_file}
}

#------------------------------------------------------------------------------
# modify variables
#------------------------------------------------------------------------------
modify_variables ()
{
    local _mv_modified
    local _mv_output_file

    _mv_modified=0
    _mv_output_file=`mktemp -t ${module_name}.XXXXXXXXX`

    if [ ${_mv_modified} -eq 1 ]
    then
        modflag=1
        myecho --pack ${module_name} --force-output "modifying parameter(s) ..."
        cat ${_mv_output_file}
        myecho --pack ${module_name} --force-output --info "... read documentation for modified parameter(s)!"
    fi

    rm -f ${_mv_output_file}
}

#------------------------------------------------------------------------------
# add variables
#------------------------------------------------------------------------------
add_variables ()
{
    local _av_added
    local _av_output_file
    local _av_idx
    local _av_imax

    _av_added=0
    _av_output_file=`mktemp -t ${module_name}.XXXXXXXXX`

    if [ ${_av_added} -eq 1 ]
    then
        modflag=1
        myecho --pack ${module_name} --force-output "adding new parameter(s) ..."
        cat ${_av_output_file}
        myecho --pack ${module_name} --force-output --info "... read documentation for added parameter(s)!"
    fi

    rm -f ${_av_output_file}
}

#------------------------------------------------------------------------------
# delete variables
#------------------------------------------------------------------------------
delete_variables ()
{
    local _dv_deleted
    local _dv_output_file

    _dv_deleted=0
    _dv_output_file=`mktemp -t ${module_name}.XXXXXXXXX`

    if [ ${_dv_deleted} -eq 1 ]
    then
        modflag=1
        myecho --pack ${module_name} "deleting old parameters ..."
        cat ${_dv_output_file}
    fi

    rm -f ${_dv_output_file}
}

#------------------------------------------------------------------------------
# create new configuration
#------------------------------------------------------------------------------
create_config ()
{
    myecho --pack ${module_name} "updating/creating configuration ..."

    {
        #------------------------------------------------------------------------------
        printgpl -conf "${module_name}" "2020-05-25" "jed"
        #------------------------------------------------------------------------------

        if [ "${MAIL_PANDA_DO_DEBUG}" = 'yes' -o "${MAIL_PANDA_DO_DEBUG}" = 'no' ]
        then
            # debug active
            printvar "PANDA_DO_DEBUG" "debug mode: yes or no"
            echo
        else
            # debug parameter exists but not active
            if [ -n "`grep MAIL_PANDA_DO_DEBUG ${source_conf}`" ]
            then
                echo "# MAIL_PANDA_DO_DEBUG='yes'           # debug mode: yes or no"
                echo
            fi
        fi

        #------------------------------------------------------------------------------
        printgroup "general settings"
        #------------------------------------------------------------------------------

        printvar "START_MAIL_PANDA"       "activate configuration: yes or no"

        #------------------------------------------------------------------------------
        printend
        #------------------------------------------------------------------------------
    } > ${generate_conf}
}

#==============================================================================
# main
#==============================================================================

module_name='mail-panda'

configfile=/etc/config.d/${module_name}
installfile=/var/run/${module_name}.install

# setting defaults
source_conf=${installfile}
generate_conf=${configfile}

goflag=0
modflag=0

case "${1}" in
    update )
        goflag=1
        ;;
    test )
        source_conf=${configfile}

        generate_conf=/etc/config.d/${module_name}.test
        goflag=1
        ;;
    * )
        echo
        echo "Use one of the following options:"
        echo
        echo "  ${module_name}-update.sh [update] - the file ${configfile}.import will be read, the configuration"
        echo "                             will be checked and an updated configuration file will be written."
        echo
        goflag=0
esac

if [ ${goflag} -eq 1 ]
then
    if [ -f ${source_conf} ]
    then
        myecho --pack ${module_name} --info "previous configuration found ..."
        . ${source_conf}

        rename_variables
        modify_variables
        add_variables
        delete_variables

        create_config
    else
        myecho --pack ${module_name} --force-output --error "no configuration ${source_conf} found - exiting."
        myanykey --pack ${module_name}
    fi
fi

#==============================================================================
# end
#==============================================================================
exit 0
